
import numpy as np
import matplotlib.pyplot as plt
from mpl_toolkits.mplot3d import Axes3D

def plot3D(data, domain_size, domain_resolution,name):
    """
    Plot a 3D field using a scatter plot.

    Parameters
    ----------
    data : np.ndarray
        3D field to plot.
    domain_size : tuple
        Size of the domain.
    domain_resolution : tuple
        Resolution of the domain.
    """


    # Create a grid for plotting
    x = np.linspace(0, domain_size[0], domain_resolution[0])
    y = np.linspace(0, domain_size[1], domain_resolution[1])
    z = np.linspace(0, domain_size[2], domain_resolution[2])
    X, Y, Z = np.meshgrid(x, y, z, indexing='ij')

    # Plot the 3D pressure field
    fig = plt.figure()
    ax = fig.add_subplot(111, projection='3d')
    ax.set_title(f'3D {name} Field')

    # Flatten the arrays for plotting
    X_flat = X.flatten()
    Y_flat = Y.flatten()
    Z_flat = Z.flatten()
    data_flat = data.flatten()

    # Create a scatter plot
    scat = ax.scatter(X_flat, Y_flat, Z_flat, c=data_flat, cmap='viridis')

    # Add color bar
    cbar = plt.colorbar(scat, ax=ax, shrink=0.5, aspect=5)
    cbar.set_label(name)

    # Set labels
    ax.set_xlabel('X')
    ax.set_ylabel('Y')
    ax.set_zlabel('Z')

    plt.show()