import numpy as np
from pyTurbulence.syntheticTurbulence import compute_thermodynamic_fields

def test_compute_thermodynamic_fields():
    # Define test parameters
    mean_density = 4.0
    mean_pressure = 3.0
    mean_temperature = 3.0
    gamma = 1.4
    Mt = 0.3
    xi = gamma*Mt**2
    case = 1

    # Create a simple incompressible pressure fluctuation field
    nx, ny, nz = 5, 5, 5
    incompressible_pressure_fluctuations = np.random.rand(nx, ny, nz)

    # Compute the thermodynamic fields
    density, pressure, temperature = compute_thermodynamic_fields(
        mean_density, mean_pressure, mean_temperature, 
        incompressible_pressure_fluctuations, gamma, Mt, case
    )

    # Define the expected results for case 1
    compressible_pressure_fluctuations = incompressible_pressure_fluctuations * xi
    expected_density = mean_density * (1.0 + compressible_pressure_fluctuations)
    expected_pressure = mean_pressure * (1.0 + compressible_pressure_fluctuations)
    expected_temperature = mean_temperature * (1.0 + compressible_pressure_fluctuations)

    # Test the results for case 1
    assert np.allclose(density, expected_density, atol=1e-6), "Test failed: density does not match expected results for case 1"
    assert np.allclose(pressure, expected_pressure, atol=1e-6), "Test failed: pressure does not match expected results for case 1"
    assert np.allclose(temperature, expected_temperature, atol=1e-6), "Test failed: temperature does not match expected results for case 1"

    # Change to case 2 and recompute
    case = 2
    density, pressure, temperature = compute_thermodynamic_fields(
        mean_density, mean_pressure, mean_temperature, 
        incompressible_pressure_fluctuations, gamma, Mt, case
    )

    # Define the expected results for case 2
    compressible_density_fluctuations = compressible_pressure_fluctuations * Mt**2
    compressible_temperature_fluctuations = compressible_pressure_fluctuations * Mt**2 * (gamma - 1)
    expected_density = mean_density * (1.0 + compressible_density_fluctuations)
    expected_pressure = mean_pressure * (1.0 + compressible_pressure_fluctuations)
    expected_temperature = mean_temperature * (1.0 + compressible_temperature_fluctuations)

    # Test the results for case 2
    assert np.allclose(density, expected_density, atol=1e-6), "Test failed: density does not match expected results for case 2"
    assert np.allclose(pressure, expected_pressure, atol=1e-6), "Test failed: pressure does not match expected results for case 2"
    assert np.allclose(temperature, expected_temperature, atol=1e-6), "Test failed: temperature does not match expected results for case 2"